@@ -7,10 +7,10 @@ use winapi::um::winnt;
 
 #[cfg(unix)]
 lazy_static! {
-	pub static ref PAGE_SIZE: usize = {
-		use libc::{sysconf, _SC_PAGE_SIZE};
+	pub static ref GRANULARITY: usize = {
+		use libc::{sysconf, _SC_PAGESIZE};
 
-		let pg = unsafe { sysconf(_SC_PAGE_SIZE) };
+		let pg = unsafe { sysconf(_SC_PAGESIZE) };
 		assert!(pg > 0);
 
 		pg.try_into().unwrap()
@@ -19,13 +19,13 @@ lazy_static! {
 
 #[cfg(windows)]
 lazy_static! {
-	pub static ref PAGE_SIZE: usize = {
+	pub static ref GRANULARITY: usize = {
 		use std::mem::MaybeUninit;
 		use winapi::um::sysinfoapi::{SYSTEM_INFO, GetSystemInfo};
 
 		let mut si = MaybeUninit::<SYSTEM_INFO>::uninit();
 		unsafe { GetSystemInfo(si.as_mut_ptr()); }
-		unsafe { si.assume_init() }.dwPageSize.try_into().unwrap()
+		unsafe { si.assume_init() }.dwAllocationGranularity.try_into().unwrap()
 	};
 }
 
@@ -45,14 +45,18 @@ pub enum Protection {
 	ReadWrite = winnt::PAGE_READWRITE,
 }
 
+pub fn is_power_of_two(num: usize) -> bool {
+	num != 0 && (num & (num - 1)) == 0
+}
+
 pub fn align(offset: usize, align: usize) -> usize {
-	debug_assert!(align != 0 && (align & (align - 1)) == 0);
+	debug_assert!(is_power_of_two(align));
 
 	(offset + (align - 1)) & !(align - 1)
 }
 
-pub fn page_align(offset: usize) -> usize {
-	align(offset, *PAGE_SIZE)
+pub fn alloc_align(offset: usize) -> usize {
+	align(offset, *GRANULARITY)
 }
 
 pub unsafe fn zero(addr: *mut u8, size: usize) {
@@ -197,6 +201,37 @@ pub unsafe fn unlock(addr: *mut u8, size: usize) -> Result<(), Error> {
 mod tests {
 	use super::*;
 
+	#[test]
+	fn test_alloc_size() {
+		assert!(is_power_of_two(*GRANULARITY));
+
+		// No modern architecture has a page size < 4096 bytes
+		assert!(*GRANULARITY >= 4096);
+	}
+
+	#[test]
+	fn test_is_power_of_two() {
+		let mut p = 2;
+
+		while p < usize::MAX / 2 {
+			assert!(is_power_of_two(p));
+			p *= 2;
+		}
+	}
+
+	#[test]
+	fn test_not_is_power_of_two() {
+		let mut p = 2;
+
+		while p <= 4194304 {
+			for q in p + 1 .. p * 2 {
+				assert!(!is_power_of_two(q));
+			}
+
+			p *= 2;
+		}
+	}
+
 	#[test]
 	fn test_align() {
 		assert_eq!(align(0, 4096), 0);
